<?php
/*
 * Plugin Name:       Woo Move Category Description (EasyToolsWP)
 * Description:       Moves category description below products in WooCommerce.
 * Version:           1.0.1
 * Requires at least: 6.6
 * Author:            EasyToolsWP.com
 * Requires Plugins:  woocommerce
 */

// Flyt kategori beskrivelse ned under produkterne
function move_category_description() {
    remove_action( 'woocommerce_archive_description', 'woocommerce_taxonomy_archive_description', 10 );
    add_action( 'woocommerce_after_shop_loop', 'custom_woocommerce_taxonomy_archive_description', 5 );
}
add_action( 'init', 'move_category_description' );

// Tilpasning af kategori beskrivelse for at tillade h2, h3 og  h1 tags
function custom_woocommerce_taxonomy_archive_description() {
    if ( is_product_category() ) {
        $term = get_queried_object();
        $description = apply_filters( 'woocommerce_term_archive_description', $term->description );
        if ( $description ) {
            // Check for custom H1 tag
            preg_match('/<h1>(.*?)<\/h1>/', $description, $matches);
            if (!empty($matches[0])) {
                $description = str_replace($matches[0], '', $description); // Remove custom H1 tag
                echo $matches[0]; // Output custom H1 tag
            }
            ?>
            <div class="woocommerce-archive-description">
                <?php echo apply_filters( 'woocommerce_format_content', wpautop( wp_kses_post( $description ) ) ); ?>
            </div>
            <?php
        }
    }
}

// Tilladelse af h2, h3 og custom h1 tags i kategori beskrivelsen
function allow_additional_tags_in_category_description( $allowedtags ) {
    $allowedtags['h1'] = array();
    $allowedtags['h2'] = array();
    $allowedtags['h3'] = array();
    return $allowedtags;
}
add_filter( 'wp_kses_allowed_html', 'allow_additional_tags_in_category_description', 10, 1 );

// Erstat den originale H1 overskrift
function replace_woocommerce_page_title() {
    if ( is_product_category() ) {
        remove_action( 'woocommerce_before_main_content', 'woocommerce_page_title', 20 );
        add_action( 'woocommerce_before_main_content', 'custom_woocommerce_page_title', 20 );
    }
}
add_action( 'init', 'replace_woocommerce_page_title' );

function custom_woocommerce_page_title() {
    $term = get_queried_object();
    $category_title = $term->name;
    echo '<h1 class="woocommerce-products-header__title page-title">' . $category_title . '</h1>';
}
